use clap::{Parser, Subcommand};

mod mnemonic;

/// The Kitchen Sink of Entropy.
#[derive(Parser, Clone, Debug)]
#[command(author, version, about, long_about = None)]
pub struct Keyfork {
    // Global options
    #[command(subcommand)]
    pub command: KeyforkCommands,
}

#[derive(Subcommand, Clone, Debug)]
pub enum KeyforkCommands {
    /// Mnemonic generation and persistence utilities.
    Mnemonic(mnemonic::Mnemonic),
    
    /// Seeded data generation utility.
    Seed(keyfork_seed::cli::Command),

    /// Keyforkd background daemon to manage seed creation.
    Daemon,
}

impl KeyforkCommands {
    pub fn handle(&self, keyfork: &Keyfork) -> Result<(), Box<dyn std::error::Error>> {
        match self {
            KeyforkCommands::Mnemonic(m) => {
                m.command.handle(m, self, keyfork)?;
            }
            KeyforkCommands::Seed(s) => {
                let response = s.handle()?;
                println!("{response:?}");
            }
            KeyforkCommands::Daemon => {
                todo!()
            }
        }
        Ok(())
    }
}
